# DRAGONS

[![Tests](https://github.com/kilonzi/dragons/actions/workflows/package-build.yml/badge.svg?branch=main)](https://github.com/kilonzi/dragons/actions/workflows/package-build.yml)

Releases the dragons to test the performance of Motorcade and Portal
